module ContentManagement
  class ViewController < ContentManagementController

    # Handler for content search
    def content_by_filter_terms
      filter_terms = params[:filter].split(/\+/)
      filter_terms.each do |keyword|
        tag = ::ContentManagement::Tag.find_by_name(params[:tag])
        @contents += tag.contents unless tag.nil?
      end
    end

    # Handler for selection from tag cloud
    def content_by_tag
      @tag      = ::ContentManagement::Tag.find_by_name(params[:tag])
      @contents = @tag.contents

      @page_title = "Contents tagged with #{@tag.name}"
      render :action => 'list_content'
    end

    def content_by_permalink
      @content = ::ContentManagement::Content.find_by_permalink(params[:permalink])
      render :template => "content_management/view/show"
    end

    def comment_by_permalink
      @content = ::ContentManagement::Content.find_by_permalink(params[:permalink])
    end

    def blogs_by_date
      contents_by_date(::ContentManagement::ContentType::Blog, params[:y], params[:m], params[:d])
    end

    def articles_by_date
      contents_by_date(::ContentManagement::ContentType::Article, params[:y], params[:m], params[:d])
    end

    def faqs_by_date
      contents_by_date(::ContentManagement::ContentType::FAQ, params[:y], params[:m], params[:d])
    end

    #---------------------------------------------------------------------------

    def googlesitemap
      @static_pages = ::ContentManagement::Content
      .where(
        :content_type => ::ContentManagement::ContentType.find_by(:name => ::ContentManagement::ContentType::StaticPage),
        #:select => 'id, title, created_at, updated_at',
        :approved => true,
      )
      .order(:updated_at => :desc)
      .limit(50000)

      @articles = ::ContentManagement::Content
      .where(
        :content_type => ::ContentManagement::ContentType.find_by(:name => ::ContentManagement::ContentType::Article),
        #:select => 'id, title, created_at, updated_at',
        :approved => true,
      )
      .order(:updated_at => :desc)
      .limit(50000)

      @blogs = ::ContentManagement::Content
      .where(
        :content_type => ::ContentManagement::ContentType.find_by(:name => ::ContentManagement::ContentType::Blog),
        #:select => 'id, title, created_at, updated_at',
        :approved => true,
      )
      .order(:updated_at => :desc)
      .limit(50000)

      @faqs = ::ContentManagement::Content
      .where(
        :content_type => ::ContentManagement::ContentType.find_by(:name => ::ContentManagement::ContentType::FAQ),
        #:select => 'id, title, created_at, updated_at',
        :approved => true,
      )
      .order(:updated_at => :desc)
      .limit(50000)

      # set last modified header to the date of the latest entry.
      #headers["Last-Modified"] = @entries[0].updated_at.httpdate
      headers["Content-Type"] = "text/xml"

      #respond_to  do |format|
      #  format.xml { } # googlesitemap.xml.builder
      #end
      render :layout => false #, :xml => 'googlesitemap.xml.builder'
      #render :xml => { :name => 'Everard' }.to_xml
    end

    #---------------------------------------------------------------------------

    def calendar_icon
      # font storage directory
      fontlib_path = ::ContentManagement::Engine.root.join('app','assets','fonts','content_management').to_s
      # image library directory
      imagelib_path = ::ContentManagement::Engine.root.join('app','assets','images','content_management').to_s
      # image cache directory
      cache_path = ::Rails.root.join('tmp', 'cache', 'assets', ::Rails.env).to_s

      day   = params[:d] ? params[:d].to_i : Time.now.day
      month = params[:m] ? params[:m].to_i : Time.now.mon
      year  = params[:y] ? params[:y].to_i : Time.now.year
      month_name = t('date.month_names')[month]

      font_path = fontlib_path + '/' + 'arial.ttf'
      image_path = imagelib_path + '/' + 'calendar_blank.png'
      cached_image = cache_path + '/' + 'new-image.png'

      #image = ::Magick::ImageList.new(image_path)
      image = ::Magick::Image.read(image_path).first
      image.resize! 90, 110
      image_width = image.x_resolution.to_i

      text = ::Magick::Draw.new

      # annotate(img, width, height, x, y, text) [ { additional parameters } ]
      text.annotate(image, 0, 0, 0, 25, month_name) {
        self.gravity = ::Magick::CenterGravity
        self.gravity = ::Magick::NorthGravity
        self.pointsize = 15
        self.stroke = 'transparent'
        self.fill = '#FFFFFF'
        self.font = font_path
        self.font_weight = ::Magick::BoldWeight
      }

      text.annotate(image, 0, 0, -2, 10, day.to_s) {
        self.gravity = ::Magick::CenterGravity
        #self.gravity = ::Magick::NorthGravity
        self.pointsize = 30
        self.stroke = 'transparent'
        self.fill = '#000000'
        self.font = font_path
        self.font_weight = ::Magick::BoldWeight
      }

      text.annotate(image, 0, 0, 0, 10, year.to_s) {
        self.gravity = ::Magick::CenterGravity
        self.gravity = ::Magick::SouthGravity
        self.pointsize = 15
        self.stroke = 'transparent'
        self.fill = '#000000'
        self.font = font_path
        self.font_weight = ::Magick::BoldWeight
      }

      image.resize! 60, 80

      send_data(image.to_blob, :type => 'image/jpg', :disposition => 'inline')
    end

    #---------------------------------------------------------------------------

    private

    def contents_by_date(type, year=nil, month=nil, day=nil)
      if year.nil?
        @contents = ::ContentManagement::Content.where( :content_type_id => ::ContentManagement::ContentType.find_by_name(type) )
      elsif month.nil?
        @contents = ::ContentManagement::Content.where( :content_type_id => ::ContentManagement::ContentType.find_by_name(type) ).created_in_year( year )
      elsif day.nil?
        @contents = ::ContentManagement::Content.where( :content_type_id => ::ContentManagement::ContentType.find_by_name(type) ).created_in_month( year, month )
      else
        @contents = ::ContentManagement::Content.where( :content_type_id => ::ContentManagement::ContentType.find_by_name(type) ).created_on( year, month, day )
      end

      @page_title = "#{type} content#{year.nil? ? '' : ' for '}#{day.nil? ? (month.nil? ? (year.nil? ? '' : "#{year}") : "#{t('date.month_names')[month]}-#{year}") : "#{day}-#{month}-#{year}"}"
      render :action => 'list_content'
    end
  end
end