module ContentManagement
  module ContentManagementHelper

    def title(page_title)
      content_for(:title) { page_title }
    end

    def javascript(*files)
      content_for(:head) { javascript_include_tag(*files) }
    end

    def stylesheet(*files)
      content_for(:head) { stylesheet_link_tag(*files) }
    end

    #---------------------------------------------------------------------------

    def permalink(content)
      case content.content_type.name
      when ::ContentManagement::ContentType::StaticPage then
        "#{static_page_by_permalink_url(:permalink => content.permalink)}"
      when ::ContentManagement::ContentType::Article then
        "#{article_by_permalink_url(:permalink => content.permalink)}"
      when ::ContentManagement::ContentType::Blog then
        "#{blog_by_permalink_url(:permalink => content.permalink)}"
      when ::ContentManagement::ContentType::FAQ then
        "#{faq_by_permalink_url(:permalink => content.permalink)}"
      else
        ''
      end
    end

    def permalink_link_to(content)
      "#{link_to(content.title, permalink(content))}"
    end

    #private

    # Handler to send application URIs back to the application
    def method_missing(method, *args, &block)
      if (method.to_s.end_with?('_path') || method.to_s.end_with?('_url')) && main_app.respond_to?(method)
        main_app.send(method, *args)
      else
        super
      end
    end

  end
end
