module ContentManagement
  class Tag < ActiveRecord::Base
    self.table_name = 'cm_tags'

    has_and_belongs_to_many :contents, :class_name => '::ContentManagement::Content', :join_table => 'cm_contents_tags'

    #---------------------------------------------------------------------------

    #attr_accessible :name, :display_name

    # Satisfy GroupingController needs.
    attr_accessor :description, :keywords

    #---------------------------------------------------------------------------

    validates_uniqueness_of :name

    #---------------------------------------------------------------------------

    before_save :ensure_naming_conventions

    #---------------------------------------------------------------------------

    def ensure_naming_conventions
      self.display_name = self.name if self.display_name.blank?
      self.name = self.display_name #.to_url
    end

    #---------------------------------------------------------------------------

    def count
      contents.length
    end

    def self.get(name)
      tagname = name #.to_url
      find_or_create_by(:name => tagname, :display_name => name)
    end

    def self.find_by_name_or_display_name(tagname, name)
      self.find(:first, :conditions => [%{name = ? OR display_name = ? OR display_name = ?}, tagname, tagname, name])
    end

    def self.find_all_with_content_counters(limit=20, orderby='content_counter DESC', start=0)
      # Only count published contents
      self.find_by_sql([%{
        SELECT tags.id, tags.name, tags.display_name, COUNT(contents_tags.content_id) AS content_counter
        FROM #{Tag.table_name} tags LEFT OUTER JOIN cm_contents_tags cm_contents_tags
          ON contents_tags.tag_id = tags.id
        LEFT OUTER JOIN #{ContentManagement::Content.table_name} contents
          ON cm_contents_tags.content_id = contents.id
        WHERE contents.published = ?
        GROUP BY tags.id, tags.name, tags.display_name
        ORDER BY #{orderby}
        LIMIT ? OFFSET ?
          },true, limit, start]).each{|item| item.content_counter = item.content_counter.to_i }
    end

    def self.merge(from, to)
      self.update_by_sql([%{UPDATE cm_contents_tags SET tag_id = #{to} WHERE tag_id = #{from} }])
    end

    def self.find_by_permalink(name)
      self.find_by_name(name)
    end

    def self.to_prefix
      'tag'
    end

    # Return all tags with the char or string
    # send by parameter
    def self.find_with_char(char)
      find :all, :conditions => ['name LIKE ? ', "%#{char}%"], :order => 'name ASC'
    end

    def self.collection_to_string tags
      tags.map(&:display_name).sort.map { |name| name =~ / / ? "\"#{name}\"" : name }.join ", "
    end

    def published_contents
      contents.already_published
    end

    def permalink
      self.name
    end

    def permalink_url(anchor=nil, only_path=false)
      content = ContentManagement::Content.default # remove me...

      content.url_for(
        :controller => 'tags',
        :action => 'show',
        :id => permalink,
        :only_path => only_path
      )
    end

    def to_param
      permalink
    end
  end
end
