ContentManagement::Engine.routes.draw do

  # Sitemap
  get 'sitemap', :as => 'sitemap', :to => 'view#googlesitemap', :defaults => {:format => 'xml'}

  # View content with supplied tag
  get 'view/tags/:tag', :as => :content_by_tag, :to => 'view#content_by_tag', :defaults => {:tag => nil}
  get 'view/filter_terms/:filter', :as => :content_by_filter_terms, :to => 'view#content_by_filter_terms', :defaults => {:filter => nil}

  # Access contents by date (or all)
  get 'blogs(/:y(/:m(/:d)))', :as => 'blogs', :to => 'view#blogs_by_date', :defaults => {:d => nil, :m => nil, :y => nil}
  get 'articles(/:y(/:m(/:d)))', :as => 'articles', :to => 'view#articles_by_date', :defaults => {:d => nil, :m => nil, :y => nil}
  get 'faqs(/:y(/:m(/:d)))', :as => 'faqs', :to => 'view#faqs_by_date', :defaults => {:d => nil, :m => nil, :y => nil}

  # Access specific comment from content
  get 'blog/:permalink/comment(#:reference)', :as => 'blog_comment', :to => 'view#comment_by_permalink', :defaults => {:reference => nil}
  get 'article/:permalink/comment(#:reference)', :as => 'article_comment', :to => 'view#comment_by_permalink', :defaults => {:reference => nil}
  get 'faq/:permalink/comment(#:reference)', :as => 'faq_comment', :to => 'view#comment_by_permalink', :defaults => {:reference => nil}
  get 'content/:permalink/comment(#:reference)', :as => 'content_comment', :to => 'view#comment_by_permalink', :defaults => {:reference => nil}

  # Access content by permalink
  get 'static_page/:permalink', :as => 'static_page_by_permalink', :to => 'view#content_by_permalink'
  get 'blog/:permalink', :as => 'blog_by_permalink', :to => 'view#content_by_permalink'
  get 'article/:permalink', :as => 'article_by_permalink', :to => 'view#content_by_permalink'
  get 'faq/:permalink', :as => 'faq_by_permalink', :to => 'view#content_by_permalink'
  get 'content/:permalink', :as => 'content_by_permalink', :to => 'view#content_by_permalink'

  # Utility routes
  get 'calendar_icon(/:d/:m/:y)', :as => 'calendar_icon', :to => 'view#calendar_icon', :defaults => {:d => nil, :m => nil, :y => nil}

  # Handlers for CKEditor extension
  get 'ckeditor_assets/attachments/:id/:filename' => 'assets#attachments'
  get 'ckeditor_assets/pictures/:id/:style' => 'assets#pictures'

  # Default handlers
  #namespace :admin do
  scope :module => "admin" do

    resources :contents do
      resources :comments
      resources :trackbacks
    end

    resources :comments
    resources :content_statuses
    resources :content_categories
    resources :content_audiences
    resources :trackbacks
  end

  get 'dashboard' => 'dashboard#index'

  # Mount dependent engines if they are not directly mounted by the application (Gemfile or routes.rb)
  # - the assumption is that the application will handle the mount path
  # - we must handle non-deterministic load/mount order of dependent engines
  [:asset_management].each do |engine|
    #unless Rails.application.config.eager_load_namespaces.include?("#{engine.capitalize}::Engine".constantize.class)
    #unless Rails.application.routes.named_routes.routes.keys.include?(engine)
    unless Rails.application.routes.named_routes.key?(engine)
      mount "::#{engine.to_s.camelize}::Engine".constantize => "/#{engine.to_s}", :as => engine
    end
  end

  root :to => "dashboard#index"
end
