class ContentManagementInitialSchema < ActiveRecord::Migration[4.2]
  def change

    ActiveRecord::Base.transaction do
      create_table :cm_settings do |t|
        t.string :name, :null => false
        t.string :value
        t.integer :position
      end

      add_index :cm_settings, :name

      create_table :cm_content_formats do |t|
        t.string :name, :null => false
        t.text :description
        #t.timestamps :null => false
      end

      add_index :cm_content_formats, :name #, :unique => true

      create_table :cm_content_types do |t|
        t.string :name, :null => false
        t.text :description
        #t.timestamps :null => false
      end

      add_index :cm_content_types, :name #, :unique => true

      create_table :cm_content_audiences do |t|
        t.string :name, :null => false
        t.text :description
        #t.timestamps :null => false
      end

      add_index :cm_content_audiences, :name #, :unique => true

      create_table :cm_content_categories do |t|
        t.string :name, :null => false
        t.text :description
        t.integer :position, :default => 1
        t.boolean :active, :default => true

        t.belongs_to :content_type, :null => false

        t.timestamps :null => false
      end

      add_index :cm_content_categories, [:name, :content_type_id] #, :unique => true

      create_table :cm_content_statuses do |t|
        t.string :name, :null => false
        t.text :description
        #t.timestamps :null => false
      end

      add_index :cm_content_statuses, :name #, :unique => true

      create_table :cm_contents do |t|
        t.string :title, :null => false
        t.string :permalink
        t.integer :version
        t.text :body
        t.text :extension
        t.text :excerpt
        t.string :keywords
        t.boolean :approved, :default => false
        t.datetime :allow_comments_until, :default => nil
        t.integer :comments_count
        t.boolean :allow_hit_counts
        t.integer :hit_count
        t.datetime :published_at, :default => nil
        t.datetime :expires_at, :default => nil
        t.string :text_filter
        t.string :user_agent
        t.string :referrer
        t.string :ip_address

        t.belongs_to :content_format, :null => false
        t.belongs_to :content_category, :null => false
        t.belongs_to :content_type, :null => false
        t.belongs_to :content_audience, :null => false
        t.belongs_to :content_status, :null => false

        t.references :owner, :polymorphic => true

        t.timestamps :null => false
      end

      add_index :cm_contents, :permalink

      create_table :cm_comments do |t|
        t.belongs_to :content, :null => false

        t.string :title
        t.string :author, :null => false
        t.string :email, :null => false
        t.string :url
        t.text :body, :null => false
        t.boolean :approved, :default => false
        t.string :ip

        t.timestamps :null => false
      end

      add_index :cm_comments, :content_id

      create_table :cm_trackbacks do |t|
        t.belongs_to :content, :null => false

        t.string :site_name
        t.string :title
        t.string :excerpt
        t.string :url
        t.string :ip

        t.timestamps :null => false
      end

      add_index :cm_trackbacks, :content_id

      create_table :cm_tags do |t|
        t.string :name
        t.string :display_name

        t.timestamps :null => false
      end

      add_index :cm_tags, :name

      create_table :cm_contents_tags, :id => false do |t|
        t.integer :content_id
        t.integer :tag_id
      end

      add_index :cm_contents_tags, [:content_id, :tag_id], :unique => true
    end

  end
end
